==> pentobi_1.1.orig.tar.gz: pentobi-1.1/src/libpentobi_base/Color.cpp <==
//-----------------------------------------------------------------------------
/** @file libpentobi_base/Color.cpp */
//-----------------------------------------------------------------------------

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "Color.h"

#include <sstream>
#include <boost/algorithm/string/case_conv.hpp>
#include <boost/format.hpp>

namespace libpentobi_base {

using namespace std;
using boost::algorithm::to_lower;
using boost::format;

//-----------------------------------------------------------------------------

Color::Color(const string& s)
{
    istringstream in(s);
    in >> *this;
    if (! in)
        throw InvalidString(str(format("Invalid color string '%1%'") % s));
}

//-----------------------------------------------------------------------------

ostream& operator<<(ostream& out, const Color& c)
{
    out << "Color" << (c.to_int() + 1);
    return out;
}

istream& operator>>(istream& in, Color& c)
{
    string s;
    in >> s;
    if (in)
    {
        to_lower(s);
        if (s == "color1" || s == "b" || s == "black")
        {
            c = Color(0);
            return in;
        }
        else if (s == "color2" || s == "w" || s == "white")
        {
            c = Color(1);
            return in;
        }
        else if (s == "color3")
        {
            c = Color(2);
            return in;
        }
        else if (s == "color4")
        {
            c = Color(3);
            return in;
        }
    }
    in.setstate(ios::failbit);
    return in;
}

//-----------------------------------------------------------------------------

} // namespace libpentobi_base

==> pentobi_7.2.orig.tar.gz: pentobi-7.2/src/libpentobi_base/Color.cpp <==
//-----------------------------------------------------------------------------
/** @file libpentobi_base/Color.cpp */
//-----------------------------------------------------------------------------

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "Color.h"

#include <sstream>
#include "libboardgame_util/StringUtil.h"

namespace libpentobi_base {

using namespace std;
using libboardgame_util::to_lower;

//-----------------------------------------------------------------------------

Color::Color(const string& s)
{
    istringstream in(s);
    in >> *this;
    if (! in)
        throw InvalidString("Invalid color string '" + s + "'");
}

//-----------------------------------------------------------------------------

ostream& operator<<(ostream& out, const Color& c)
{
    out << (c.to_int() + 1);
    return out;
}

istream& operator>>(istream& in, Color& c)
{
    string s;
    in >> s;
    if (in)
    {
        s = to_lower(s);
        if (s == "1" || s == "b" || s == "black")
        {
            c = Color(0);
            return in;
        }
        else if (s == "2" || s == "w" || s == "white")
        {
            c = Color(1);
            return in;
        }
        else if (s == "3")
        {
            c = Color(2);
            return in;
        }
        else if (s == "4")
        {
            c = Color(3);
            return in;
        }
    }
    in.setstate(ios::failbit);
    return in;
}

//-----------------------------------------------------------------------------

} // namespace libpentobi_base
